summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kolibs/koUnitWidgets.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/3rdparty/kolibs/koUnitWidgets.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/3rdparty/kolibs/koUnitWidgets.h')
-rw-r--r--kexi/3rdparty/kolibs/koUnitWidgets.h36
1 files changed, 20 insertions, 16 deletions
diff --git a/kexi/3rdparty/kolibs/koUnitWidgets.h b/kexi/3rdparty/kolibs/koUnitWidgets.h
index 957b1b36..dbdcb9c0 100644
--- a/kexi/3rdparty/kolibs/koUnitWidgets.h
+++ b/kexi/3rdparty/kolibs/koUnitWidgets.h
@@ -44,9 +44,9 @@ class KoUnitDoubleBase;
class KOFFICEUI_EXPORT KoUnitDoubleValidator : public KDoubleValidator
{
public:
- KoUnitDoubleValidator( KoUnitDoubleBase *base, QObject *parent, const char *name = 0 );
+ KoUnitDoubleValidator( KoUnitDoubleBase *base, TQObject *tqparent, const char *name = 0 );
- virtual QValidator::State validate( QString &, int & ) const;
+ virtual TQValidator::State validate( TQString &, int & ) const;
private:
KoUnitDoubleBase *m_base;
@@ -80,14 +80,14 @@ protected:
* @param value the number as double
* @return the resulting string
*/
- QString getVisibleText( double value ) const;
+ TQString getVisibleText( double value ) const;
/**
* Transfrom a string into a double, while taking care of locale specific symbols.
* @param str the string to transform into a number
* @param ok true, if the conversion was succesful
* @return the value as double
*/
- double toDouble( const QString& str, bool* ok ) const;
+ double toDouble( const TQString& str, bool* ok ) const;
protected:
KoUnitDoubleValidator *m_validator;
@@ -107,10 +107,11 @@ protected:
class KOFFICEUI_EXPORT KoUnitDoubleSpinBox : public KDoubleSpinBox, public KoUnitDoubleBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- KoUnitDoubleSpinBox( QWidget *parent = 0L, const char *name = 0L );
+ KoUnitDoubleSpinBox( TQWidget *tqparent = 0L, const char *name = 0L );
// lower, upper, step and value are in pt
- KoUnitDoubleSpinBox( QWidget *parent, double lower, double upper, double step, double value = 0.0,
+ KoUnitDoubleSpinBox( TQWidget *tqparent, double lower, double upper, double step, double value = 0.0,
KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
// added so the class can be used in .ui files(by Tymoteusz Majewski, maju7@o2.pl)
virtual void changeValue( double );
@@ -135,7 +136,7 @@ public:
void setMinMaxStep( double min, double max, double step );
signals:
/// emitted like valueChanged in the parent, but this one emits the point value
void valueChangedPt( double );
@@ -157,9 +158,10 @@ private slots:
class KOFFICEUI_EXPORT KoUnitDoubleLineEdit : public KLineEdit, public KoUnitDoubleBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- KoUnitDoubleLineEdit( QWidget *parent = 0L, const char *name = 0L );
- KoUnitDoubleLineEdit( QWidget *parent, double lower, double upper, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
+ KoUnitDoubleLineEdit( TQWidget *tqparent = 0L, const char *name = 0L );
+ KoUnitDoubleLineEdit( TQWidget *tqparent, double lower, double upper, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
virtual void changeValue( double );
virtual void setUnit( KoUnit::Unit = KoUnit::U_PT );
@@ -168,7 +170,7 @@ public:
double value( void ) const;
protected:
- bool eventFilter( QObject* obj, QEvent* ev );
+ bool eventFilter( TQObject* obj, TQEvent* ev );
private:
double m_value;
@@ -185,9 +187,10 @@ private:
class KOFFICEUI_EXPORT KoUnitDoubleComboBox : public KComboBox, public KoUnitDoubleBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- KoUnitDoubleComboBox( QWidget *parent = 0L, const char *name = 0L );
- KoUnitDoubleComboBox( QWidget *parent, double lower, double upper, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
+ KoUnitDoubleComboBox( TQWidget *tqparent = 0L, const char *name = 0L );
+ KoUnitDoubleComboBox( TQWidget *tqparent, double lower, double upper, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
virtual void changeValue( double );
void updateValue( double );
@@ -198,7 +201,7 @@ public:
void insertItem( double, int index = -1 );
protected:
- bool eventFilter( QObject* obj, QEvent* ev );
+ bool eventFilter( TQObject* obj, TQEvent* ev );
signals:
void valueChanged(double);
@@ -218,12 +221,13 @@ protected:
* Combo box (with spin control) for double precision numbers with unit display
* \since 1.4 (change of behavior)
*/
-class KOFFICEUI_EXPORT KoUnitDoubleSpinComboBox : public QWidget
+class KOFFICEUI_EXPORT KoUnitDoubleSpinComboBox : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- KoUnitDoubleSpinComboBox( QWidget *parent = 0L, const char *name = 0L );
- KoUnitDoubleSpinComboBox( QWidget *parent, double lower, double upper, double step, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
+ KoUnitDoubleSpinComboBox( TQWidget *tqparent = 0L, const char *name = 0L );
+ KoUnitDoubleSpinComboBox( TQWidget *tqparent, double lower, double upper, double step, double value = 0.0, KoUnit::Unit unit = KoUnit::U_PT, unsigned int precision = 2, const char *name = 0 );
void insertItem( double, int index = -1 );
void updateValue( double );
@@ -135,7 +136,7 @@ public:
void setMinMaxStep( double min, double max, double step );
signals:
- /// emitted like valueChanged in the parent, but this one emits the point value
+ /// emitted like valueChanged in the tqparent, but this one emits the point value
void valueChangedPt( double );